@@ -21,11 +21,6 @@ class MatplotlibDeprecationWarning(DeprecationWarning):
     """A class for issuing deprecation warnings for Matplotlib users."""
 
 
-# mplDeprecation is deprecated. Use MatplotlibDeprecationWarning instead.
-# remove when removing the re-import from cbook
-mplDeprecation = MatplotlibDeprecationWarning
-
-
 def _generate_deprecation_warning(
         since, message='', name='', alternative='', pending=False, obj_type='',
         addendum='', *, removal=''):
@@ -34,14 +29,17 @@ def _generate_deprecation_warning(
             raise ValueError(
                 "A pending deprecation cannot have a scheduled removal")
     else:
-        removal = f"in {removal}" if removal else "two minor releases later"
+        if not removal:
+            macro, meso, *_ = since.split('.')
+            removal = f'{macro}.{int(meso) + 2}'
+        removal = f"in {removal}"
     if not message:
         message = (
-            ("\nThe %(name)s %(obj_type)s" if obj_type else "%(name)s")
+            ("The %(name)s %(obj_type)s" if obj_type else "%(name)s")
             + (" will be deprecated in a future version"
                if pending else
-               (" was deprecated in Matplotlib %(since)s"
-                + (" and will be removed %(removal)s" if removal else "")))
+               " was deprecated in Matplotlib %(since)s and will be removed %(removal)s"
+               )
             + "."
             + (" Use %(alternative)s instead." if alternative else "")
             + (" %(addendum)s" if addendum else ""))
